package np.something.controllers;

import np.something.DTO.CustomerDto;
import np.something.model.Customer;
import np.something.services.*;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/customer")
public class CustomerController {
    private final CustomerService customerService;

    public CustomerController(CustomerService customerService) {
        this.customerService = customerService;
    }

    @GetMapping("/{id}")
    public CustomerDto getCustomer(@PathVariable Long id) {
        return new CustomerDto(customerService.findCustomer(id));
    }

    @GetMapping
    public List<CustomerDto> getCustomers() {
        return customerService.findAllCustomers().stream()
                .map(CustomerDto::new)
                .toList();
    }

    @PostMapping
    public CustomerDto createCustomer(@RequestParam("username") String username, @RequestParam("password") String password){
        final Customer customer = customerService.addCustomer(username, password);
        return new CustomerDto(customer);
    }

    @PutMapping("/{id}")
    public CustomerDto updateCustomer(@RequestParam("username") String username, @RequestParam("password") String password, @PathVariable Long id) {
        return new CustomerDto(customerService.updateCustomer(id, username, password));
    }

    @DeleteMapping("/{id}")
    public CustomerDto deleteCustomer(@PathVariable Long id) {
        return new CustomerDto(customerService.deleteCustomer(id));
    }

    @DeleteMapping
    public void deleteAllCustomers(){
        customerService.deleteAllCustomers();
    }
}
