package np.something.controllers;

import np.something.DTO.PostDto;
import np.something.services.CustomerService;
import np.something.services.PostService;
import org.springframework.web.bind.annotation.*;
import java.util.List;

@RestController
@RequestMapping("/post")
public class PostController {
    private final PostService postService;
    private final CustomerService customerService;

    public PostController(PostService postService, CustomerService customerService) {
        this.postService = postService;
        this.customerService = customerService;
    }

    @GetMapping("/{id}")
    public PostDto getPost(@PathVariable Long id) {
        return new PostDto(postService.findPost(id));
    }

    @GetMapping
    public List<PostDto> getPosts() {
        return postService.findAllPosts().stream()
                .map(PostDto::new)
                .toList();
    }

    @PostMapping
    public PostDto createPost(
            @RequestParam("title") String title,
            @RequestParam("content") String content,
            @RequestParam("authorId") Long authorId
    )
    {
        return new PostDto(postService.addPost(customerService.findCustomer(authorId), title, content));
    }

    @PutMapping("/{id}")
    public PostDto updatePost(
            @PathVariable Long id,
            @RequestParam("title") String title,
            @RequestParam("content") String content
    )
    {
        return new PostDto(postService.updatePost(id, title, content));
    }

    @DeleteMapping("/{id}")
    public PostDto deletePost (@PathVariable Long id) {
        return  new PostDto(postService.deletePost(id));
    }

    @DeleteMapping
    public void deleteAllPosts() {
        postService.deleteAllPosts();
    }
}