package np.something.model;

import jakarta.persistence.*;
import jakarta.validation.constraints.NotBlank;

import java.util.ArrayList;
import java.util.List;

@Entity
public class Post {
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    private Long id;

    @Column
    @NotBlank(message = "Title cannot be empty")
    private String title;

    @Column
    @NotBlank(message = "Content cannot be empty")
    private String content;

    @ManyToOne(fetch = FetchType.EAGER)
    @JoinColumn(name = "customer_fk")
    private Customer customer;

    @OneToMany(fetch = FetchType.EAGER, mappedBy = "post", cascade = CascadeType.ALL)
    private List<Comment> comments;

    public Post() {

    }

    public Post(Customer customer, String title, String content) {
        this.customer = customer;
        this.title = title;
        this.content = content;
        this.comments = new ArrayList<>();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        Post post = (Post) o;

        return id.equals(post.id);
    }

    @Override
    public int hashCode() {
        return id.hashCode();
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public List<Comment> getComments() {
        return comments;
    }

    public Customer getCustomer() {
        return customer;
    }

    public Long getId() {
        return id;
    }
}
