package np.something.services;

import np.something.Exceptions.CommentNotFoundException;
import org.springframework.transaction.annotation.Transactional;
import np.something.model.Comment;
import np.something.model.Customer;
import np.something.model.Post;
import np.something.repositories.CommentRepository;
import np.something.util.validation.ValidatorUtil;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Optional;

@Service
public class CommentService {
    private final CommentRepository commentRepository;
    private final ValidatorUtil validatorUtil;

    public CommentService(CommentRepository commentRepository,
                          ValidatorUtil validatorUtil) {
        this.commentRepository = commentRepository;
        this.validatorUtil = validatorUtil;
    }

    @Transactional(readOnly = true)
    public Comment findComment(Long id) {
        final Optional<Comment> comment = commentRepository.findById(id);
        return comment.orElseThrow(() -> new CommentNotFoundException(id));
    }

    @Transactional(readOnly = true)
    public List<Comment> findAllComments() {
        return commentRepository.findAll();
    }

    @Transactional
    public Comment addComment(Customer customer, Post post, String content) {
        final Comment comment = new Comment(customer, post, content);
        validatorUtil.validate(comment);
        customer.getComments().add(comment);
        post.getComments().add(comment);
        return commentRepository.save(comment);
    }

    @Transactional
    public Comment updateComment(Long id, String content) {
        final Comment currentComment = findComment(id);
        currentComment.setContent(content);
        validatorUtil.validate(currentComment);
        return commentRepository.save(currentComment);
    }

    @Transactional
    public Comment deleteComment(Long id) {
        final Comment currentComment = findComment(id);
        commentRepository.delete(currentComment);
        currentComment.getPost().getComments().remove(currentComment);
        currentComment.getCustomer().getComments().remove(currentComment);
        return currentComment;
    }

    @Transactional
    public void deleteAllComments() {
        commentRepository.deleteAll();
    }
}
