package np.something.services;

import jakarta.persistence.EntityManager;
import jakarta.persistence.EntityNotFoundException;
import jakarta.persistence.PersistenceContext;
import jakarta.transaction.Transactional;
import np.something.Exceptions.CustomerNotFoundException;
import np.something.model.Customer;
import np.something.repositories.CommentRepository;
import np.something.repositories.CustomerRepository;
import np.something.util.validation.ValidatorUtil;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.util.List;

@Service
public class CustomerService {
    private final CustomerRepository customerRepository;
    private final ValidatorUtil validatorUtil;

    public CustomerService(CustomerRepository customerRepository,
                          ValidatorUtil validatorUtil) {
        this.customerRepository = customerRepository;
        this.validatorUtil = validatorUtil;
    }

    @Transactional
    public Customer findCustomer(Long id) {
        return customerRepository.findById(id).orElseThrow(() -> new CustomerNotFoundException(id));
    }

    @Transactional
    public List<Customer> findAllCustomers() {
        return customerRepository.findAll();
    }

    @Transactional
    public Customer addCustomer(String username, String password) {
        Customer customer = new Customer(username, password);
        validatorUtil.validate(customer);
        return customerRepository.save(customer);
    }

    @Transactional
    public Customer updateCustomer(Long id, String username, String password) {
        Customer customer = findCustomer(id);
        customer.setUsername(username);
        customer.setPassword(password);
        validatorUtil.validate(customer);
        return customerRepository.save(customer);
    }

    @Transactional
    public Customer deleteCustomer(Long id) {
        Customer customer = findCustomer(id);
        customerRepository.delete(customer);
        return customer;
    }

    @Transactional
    public void deleteAllCustomers() {
        customerRepository.deleteAll();
    }
}
