package np.something.services;

import jakarta.persistence.EntityManager;
import jakarta.persistence.EntityNotFoundException;
import jakarta.persistence.PersistenceContext;
import jakarta.transaction.Transactional;
import np.something.Exceptions.PostNotFoundException;
import np.something.model.Comment;
import np.something.model.Customer;
import np.something.model.Post;
import np.something.repositories.CustomerRepository;
import np.something.repositories.PostRepository;
import np.something.util.validation.ValidatorUtil;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.util.List;

@Service
public class PostService {
    private final PostRepository postRepository;
    private final ValidatorUtil validatorUtil;

    public PostService(PostRepository postRepository,
                           ValidatorUtil validatorUtil) {
        this.postRepository = postRepository;
        this.validatorUtil = validatorUtil;
    }

    @Transactional
    public Post findPost(Long id) {
        return postRepository.findById(id).orElseThrow(() -> new PostNotFoundException(id));
    }

    @Transactional
    public List<Post> findAllPosts() {
        return postRepository.findAll();
    }

    @Transactional
    public Post addPost(Customer customer, String title, String content) {
        Post post = new Post(customer, title, content);
        validatorUtil.validate(post);
        customer.getPosts().add(post);
        return postRepository.save(post);
    }

    @Transactional
    public Post updatePost(Long id, String title, String content) {
        Post post = findPost(id);
        post.setTitle(title);
        post.setContent(content);
        validatorUtil.validate(post);
        return postRepository.save(post);
    }

    @Transactional
    public Post deletePost(Long id) {
        Post post = findPost(id);
        post.getCustomer().getPosts().remove(post);
        postRepository.delete(post);
        return post;
    }

    @Transactional
    public void deleteAllPosts() {
        postRepository.deleteAll();
    }
}
